==> xlr-api-domain-23.3.13-sources.jar: com/xebialabs/xlrelease/api/v1/views/ManagedApplicationView.java <==
package com.xebialabs.xlrelease.api.v1.views;

import com.xebialabs.xlplatform.documentation.PublicApiRef;

import java.util.Date;

@PublicApiRef
public class ManagedApplicationView {
    private String id;
    private String applicationName;
    private String managedBy;
    private Date dateCreated;
    private String environmentTag;
    private String applicationReference;
    private ConnectionServerView connectionServer;
    private String workflowId;
    private String deleteWorkflowId;
    private String updateWorkflowId;

    public static ManagedApplicationView create(String id,
                                                String applicationName,
                                                String managedBy,
                                                Date dateCreated,
                                                String environmentTag,
                                                String applicationReference,
                                                ConnectionServerView connectionServer,
                                                String workflowId,
                                                String deleteWorkflowId,
                                                String updateWorkflowId) {
        ManagedApplicationView view = new ManagedApplicationView();
        view.setId(id);
        view.setApplicationName(applicationName);
        view.setManagedBy(managedBy);
        view.setDateCreated(dateCreated);
        view.setEnvironmentTag(environmentTag);
        view.setApplicationReference(applicationReference);
        view.setConnectionServer(connectionServer);
        view.setWorkflowId(workflowId);
        view.setDeleteWorkflowId(deleteWorkflowId);
        view.setUpdateWorkflowId(updateWorkflowId);
        return view;
    }

    public String getId() {
        return id;
    }

    public void setId(final String id) {
        this.id = id;
    }

    public String getApplicationName() {
        return applicationName;
    }

    public void setApplicationName(final String applicationName) {
        this.applicationName = applicationName;
    }

    public String getManagedBy() {
        return managedBy;
    }

    public void setManagedBy(final String managedBy) {
        this.managedBy = managedBy;
    }

    public Date getDateCreated() {
        return dateCreated;
    }

    public void setDateCreated(final Date dateCreated) {
        this.dateCreated = dateCreated;
    }

    public String getEnvironmentTag() {
        return environmentTag;
    }

    public void setEnvironmentTag(final String environmentTag) {
        this.environmentTag = environmentTag;
    }

    public String getApplicationReference() {
        return applicationReference;
    }

    public void setApplicationReference(final String applicationReference) {
        this.applicationReference = applicationReference;
    }

    public ConnectionServerView getConnectionServer() {
        return connectionServer;
    }

    public void setConnectionServer(final ConnectionServerView connectionServer) {
        this.connectionServer = connectionServer;
    }

    public String getWorkflowId() {
        return workflowId;
    }

    public void setWorkflowId(String workflowId) {
        this.workflowId = workflowId;
    }

    public String getDeleteWorkflowId() {
        return deleteWorkflowId;
    }

    public void setDeleteWorkflowId(String deleteWorkflowId) {
        this.deleteWorkflowId = deleteWorkflowId;
    }

    public String getUpdateWorkflowId() {
        return updateWorkflowId;
    }

    public void setUpdateWorkflowId(String updateWorkflowId) {
        this.updateWorkflowId = updateWorkflowId;
    }
}

==> xlr-api-domain-24.1.0-sources.jar: com/xebialabs/xlrelease/api/v1/views/ManagedApplicationView.java <==
package com.xebialabs.xlrelease.api.v1.views;

import com.xebialabs.xlplatform.documentation.PublicApiRef;

import java.util.Date;

@PublicApiRef
public class ManagedApplicationView {
    private String id;
    private String applicationName;
    private String managedBy;
    private Date dateCreated;
    private String environmentTag;
    private String applicationReference;
    private ConnectionServerView connectionServer;
    private String workflowId;
    private String deleteWorkflowId;
    private String updateWorkflowId;
    private String folderId;

    public static ManagedApplicationView create(String id,
                                                String applicationName,
                                                String managedBy,
                                                Date dateCreated,
                                                String environmentTag,
                                                String applicationReference,
                                                ConnectionServerView connectionServer,
                                                String workflowId,
                                                String deleteWorkflowId,
                                                String updateWorkflowId,
                                                String folderId) {
        ManagedApplicationView view = new ManagedApplicationView();
        view.setId(id);
        view.setApplicationName(applicationName);
        view.setManagedBy(managedBy);
        view.setDateCreated(dateCreated);
        view.setEnvironmentTag(environmentTag);
        view.setApplicationReference(applicationReference);
        view.setConnectionServer(connectionServer);
        view.setWorkflowId(workflowId);
        view.setDeleteWorkflowId(deleteWorkflowId);
        view.setUpdateWorkflowId(updateWorkflowId);
        view.setFolderId(folderId);
        return view;
    }

    public String getId() {
        return id;
    }

    public void setId(final String id) {
        this.id = id;
    }

    public String getApplicationName() {
        return applicationName;
    }

    public void setApplicationName(final String applicationName) {
        this.applicationName = applicationName;
    }

    public String getManagedBy() {
        return managedBy;
    }

    public void setManagedBy(final String managedBy) {
        this.managedBy = managedBy;
    }

    public Date getDateCreated() {
        return dateCreated;
    }

    public void setDateCreated(final Date dateCreated) {
        this.dateCreated = dateCreated;
    }

    public String getEnvironmentTag() {
        return environmentTag;
    }

    public void setEnvironmentTag(final String environmentTag) {
        this.environmentTag = environmentTag;
    }

    public String getApplicationReference() {
        return applicationReference;
    }

    public void setApplicationReference(final String applicationReference) {
        this.applicationReference = applicationReference;
    }

    public ConnectionServerView getConnectionServer() {
        return connectionServer;
    }

    public void setConnectionServer(final ConnectionServerView connectionServer) {
        this.connectionServer = connectionServer;
    }

    public String getWorkflowId() {
        return workflowId;
    }

    public void setWorkflowId(String workflowId) {
        this.workflowId = workflowId;
    }

    public String getDeleteWorkflowId() {
        return deleteWorkflowId;
    }

    public void setDeleteWorkflowId(String deleteWorkflowId) {
        this.deleteWorkflowId = deleteWorkflowId;
    }

    public String getUpdateWorkflowId() {
        return updateWorkflowId;
    }

    public void setUpdateWorkflowId(String updateWorkflowId) {
        this.updateWorkflowId = updateWorkflowId;
    }

    public String getFolderId() {
        return folderId;
    }

    public void setFolderId(final String folderId) {
        this.folderId = folderId;
    }
}
